Str

Struct Str 

pub struct Str;

Implementations

Source

impl Str

pub fn after(subject: &str, search: &str) -> String

Return the remainder of a string after the first occurrence of a given value

pub fn after_last(subject: &str, search: &str) -> String

Return the remainder of a string after the last occurrence of a given value

pub fn ascii(value: &str) -> String

Transliterate a UTF-8 value to ASCII

pub fn transliterate( string: &str, unknown: Option<&str>, strict: Option<bool>, ) -> String

Transliterate a string to its closest ASCII representation

pub fn before(subject: &str, search: &str) -> String

Get the portion of a string before the first occurrence of a given value

pub fn before_last(subject: &str, search: &str) -> String

Get the portion of a string before the last occurrence of a given value

pub fn between(subject: &str, from: &str, to: &str) -> String

Get the portion of a string between two given values

pub fn between_first(subject: &str, from: &str, to: &str) -> String

Get the smallest possible portion of a string between two given values

pub fn camel(value: &str) -> String

Convert a value to camel case

pub fn char_at(subject: &str, index: isize) -> Option<char>

Get the character at the specified index

pub fn chop_start(subject: &str, needles: &[&str]) -> String

Remove the given string(s) if it exists at the start of the haystack

pub fn chop_end(subject: &str, needles: &[&str]) -> String

Remove the given string(s) if it exists at the end of the haystack

pub fn contains(haystack: &str, needles: &[&str], ignore_case: bool) -> bool

Determine if a given string contains a given substring

pub fn contains_all(haystack: &str, needles: &[&str], ignore_case: bool) -> bool

Determine if a given string contains all array values

pub fn doesnt_contain( haystack: &str, needles: &[&str], ignore_case: bool, ) -> bool

Determine if a given string doesn’t contain a given substring

pub fn convert_case(string: &str, mode: CaseMode) -> String

Convert the case of a string

pub fn deduplicate(string: &str, characters: &[char]) -> String

Replace consecutive instances of a given character with a single character

pub fn ends_with(haystack: &str, needles: &[&str]) -> bool

Determine if a given string ends with a given substring

pub fn doesnt_end_with(haystack: &str, needles: &[&str]) -> bool

Determine if a given string doesn’t end with a given substring

pub fn excerpt( text: &str, phrase: &str, options: ExcerptOptions, ) -> Option<String>

Extracts an excerpt from text that matches the first instance of a phrase

pub fn finish(value: &str, cap: &str) -> String

Cap a string with a single instance of a given value

pub fn wrap(value: &str, before: &str, after: Option<&str>) -> String

Wrap the string with the given strings

pub fn unwrap(value: &str, before: &str, after: Option<&str>) -> String

Unwrap the string with the given strings

pub fn is_pattern(patterns: &[&str], value: &str, ignore_case: bool) -> bool

Determine if a given string matches a given pattern (with wildcards)

pub fn is_ascii(value: &str) -> bool

Determine if a given string is 7 bit ASCII

pub fn is_json(value: &str) -> bool

Determine if a given value is valid JSON

pub fn is_url(value: &str, protocols: Option<&[&str]>) -> bool

Determine if a given value is a valid URL

pub fn is_uuid(value: &str, version: Option<UuidVersion>) -> bool

Determine if a given value is a valid UUID

pub fn is_ulid(value: &str) -> bool

Determine if a given value is a valid ULID

pub fn kebab(value: &str) -> String

Convert a string to kebab case

pub fn length(value: &str) -> usize

Return the length of the given string

pub fn limit( value: &str, limit: usize, end: &str, preserve_words: bool, ) -> String

Limit the number of characters in a string

pub fn lower(value: &str) -> String

Convert the given string to lower-case

pub fn words(value: &str, words: usize, end: &str) -> String

Limit the number of words in a string

pub fn markdown(string: &str, options: MarkdownOptions) -> String

Converts GitHub flavored Markdown into HTML

pub fn inline_markdown(string: &str, options: MarkdownOptions) -> String

Converts inline Markdown into HTML

pub fn mask( string: &str, character: char, index: isize, length: Option<usize>, ) -> String

Masks a portion of a string with a repeated character

pub fn match_pattern(pattern: &str, subject: &str) -> String

Get the string matching the given pattern

pub fn is_match(patterns: &[&str], value: &str) -> bool

Determine if a given string matches a given pattern

pub fn match_all(pattern: &str, subject: &str) -> Vec<String>

Get all strings matching the given pattern

pub fn numbers(value: &str) -> String

Remove all non-numeric characters from a string

pub fn pad_both(value: &str, length: usize, pad: &str) -> String

Pad both sides of a string with another

pub fn pad_left(value: &str, length: usize, pad: &str) -> String

Pad the left side of a string with another

pub fn pad_right(value: &str, length: usize, pad: &str) -> String

Pad the right side of a string with another

pub fn parse_callback( callback: &str, default: Option<&str>, ) -> (String, Option<String>)

Parse a Class[@]method style callback into class and method

pub fn plural(value: &str, count: i32, prepend_count: bool) -> String

Get the plural form of an English word

pub fn plural_studly(value: &str, count: i32) -> String

Pluralize the last word of an English, studly caps case string

pub fn plural_pascal(value: &str, count: i32) -> String

Pluralize the last word of an English, Pascal caps case string

pub fn password( length: usize, letters: bool, numbers: bool, symbols: bool, spaces: bool, ) -> String

Generate a random, secure password

pub fn position(haystack: &str, needle: &str, offset: usize) -> Option<usize>

Find the multi-byte safe position of the first occurrence of a given substring

pub fn random(length: usize) -> String

Generate a more truly “random” alpha-numeric string

pub fn create_random_strings_using<F>(factory: F)
where F: Fn(usize) -> String + Send + Sync + 'static,

Set the callable that will be used to generate random strings

pub fn create_random_strings_using_sequence(sequence: Vec<String>)

Set the sequence that will be used to generate random strings

pub fn create_random_strings_normally()

Indicate that random strings should be created normally

pub fn repeat(string: &str, times: usize) -> String

Repeat the given string

pub fn replace_array(search: &str, replace: &[&str], subject: &str) -> String

Replace a given value in the string sequentially with an array

pub fn replace( search: &[&str], replace: &[&str], subject: &str, case_sensitive: bool, ) -> String

Replace the given value in the given string

pub fn replace_first(search: &str, replace: &str, subject: &str) -> String

Replace the first occurrence of a given value in the string

pub fn replace_start(search: &str, replace: &str, subject: &str) -> String

Replace the first occurrence of the given value if it appears at the start

pub fn replace_last(search: &str, replace: &str, subject: &str) -> String

Replace the last occurrence of a given value in the string

pub fn replace_end(search: &str, replace: &str, subject: &str) -> String

Replace the last occurrence of a given value if it appears at the end

pub fn replace_matches( pattern: &str, replace: &str, subject: &str, limit: Option<usize>, ) -> String

Replace the patterns matching the given regular expression

pub fn remove(search: &[&str], subject: &str, case_sensitive: bool) -> String

Remove any occurrence of the given string in the subject

pub fn reverse(value: &str) -> String

Reverse the given string

pub fn start(value: &str, prefix: &str) -> String

Begin a string with a single instance of a given value

pub fn upper(value: &str) -> String

Convert the given string to upper-case

pub fn title(value: &str) -> String

Convert the given string to title case

pub fn headline(value: &str) -> String

Convert the given string to headline case

pub fn apa(value: &str) -> String

Convert the given string to APA-style title case

pub fn singular(value: &str) -> String

Get the singular form of an English word

pub fn slug( title: &str, separator: &str, language: Option<&str>, dictionary: Option<HashMap<String, String>>, ) -> String

Generate a URL friendly “slug” from a given string

pub fn snake(value: &str, delimiter: &str) -> String

Convert a string to snake case

pub fn trim(value: &str) -> String

Remove all whitespace from both ends of a string

pub fn trim_custom(value: &str, charlist: Option<&str>) -> String

Remove all whitespace from both ends of a string with custom character list

pub fn ltrim(value: &str, charlist: Option<&str>) -> String

Remove all whitespace from the beginning of a string

pub fn rtrim(value: &str, charlist: Option<&str>) -> String

Remove all whitespace from the end of a string

pub fn squish(value: &str) -> String

Remove all “extra” blank space from the given string

pub fn starts_with(haystack: &str, needles: &[&str]) -> bool

Determine if a given string starts with a given substring

pub fn doesnt_start_with(haystack: &str, needles: &[&str]) -> bool

Determine if a given string doesn’t start with a given substring

pub fn studly(value: &str) -> String

Convert a value to studly caps case

pub fn pascal(value: &str) -> String

Convert a value to Pascal case (alias for studly)

pub fn substr(string: &str, start: isize, length: Option<usize>) -> String

Returns the portion of the string specified by the start and length parameters

pub fn substr_count( haystack: &str, needle: &str, offset: usize, length: Option<usize>, ) -> usize

Returns the number of substring occurrences

pub fn substr_replace( string: &str, replace: &str, offset: isize, length: Option<usize>, ) -> String

Replace text within a portion of a string

pub fn swap(map: HashMap<String, String>, subject: &str) -> String

Swap multiple keywords in a string with other keywords

pub fn take(string: &str, limit: isize) -> String

Take the first or last {$limit} characters of a string

pub fn to_base64(string: &str) -> String

Convert the given string to Base64 encoding

pub fn from_base64(string: &str, strict: bool) -> Result<String, DecodeError>

Decode the given Base64 encoded string

pub fn lcfirst(string: &str) -> String

Make a string’s first character lowercase

pub fn ucfirst(string: &str) -> String

Make a string’s first character uppercase

pub fn uc_split(string: &str) -> Vec<String>

Split a string into pieces by uppercase characters

pub fn word_count(string: &str, characters: Option<&str>) -> usize

Get the number of words a string contains

pub fn word_wrap( string: &str, characters: usize, break_str: &str, cut_long_words: bool, ) -> String

Wrap a string to a given number of characters

pub fn uuid() -> Uuid

Generate a UUID (version 4)

pub fn uuid7(time: Option<DateTime<Utc>>) -> Uuid

Generate a UUID (version 7)

pub fn ordered_uuid() -> Uuid

Generate a time-ordered UUID

pub fn create_uuids_using<F>(factory: F)
where F: Fn() -> Uuid + Send + Sync + 'static,

Set the callable that will be used to generate UUIDs

pub fn create_uuids_using_sequence(sequence: Vec<Uuid>)

Set the sequence that will be used to generate UUIDs

pub fn freeze_uuids<F>(callback: Option<F>) -> Uuid
where F: FnOnce(Uuid),

Always return the same UUID when generating new UUIDs

pub fn create_uuids_normally()

Indicate that UUIDs should be created normally and not using a custom factory

pub fn ulid(time: Option<DateTime<Utc>>) -> Ulid

Generate a ULID

pub fn create_ulids_normally()

Indicate that ULIDs should be created normally and not using a custom factory

pub fn create_ulids_using<F>(factory: F)
where F: Fn() -> Ulid + Send + Sync + 'static,

Set the callable that will be used to generate ULIDs

pub fn create_ulids_using_sequence(sequence: Vec<Ulid>)

Set the sequence that will be used to generate ULIDs

pub fn freeze_ulids<F>(callback: Option<F>) -> Ulid
where F: FnOnce(Ulid),

Always return the same ULID when generating new ULIDs

pub fn flush_cache()

Remove all strings from the casing caches